package com.ruoyi.framework.system.mapper;

import java.util.List;
import com.ruoyi.framework.system.domain.Patients;

/**
 * 病患信息Mapper接口
 * 
 * @author ruoyi
 * @date 2024-11-13
 */
public interface PatientsMapper 
{
    /**
     * 查询病患信息
     * 
     * @param PatientID 病患信息主键
     * @return 病患信息
     */
    public Patients selectPatientsByPatientID(Long PatientID);

    /**
     * 查询病患信息列表
     * 
     * @param patients 病患信息
     * @return 病患信息集合
     */
    public List<Patients> selectPatientsList(Patients patients);

    /**
     * 新增病患信息
     * 
     * @param patients 病患信息
     * @return 结果
     */
    public int insertPatients(Patients patients);

    /**
     * 修改病患信息
     * 
     * @param patients 病患信息
     * @return 结果
     */
    public int updatePatients(Patients patients);

    /**
     * 删除病患信息
     * 
     * @param PatientID 病患信息主键
     * @return 结果
     */
    public int deletePatientsByPatientID(Long PatientID);

    /**
     * 批量删除病患信息
     * 
     * @param PatientIDs 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePatientsByPatientIDs(Long[] PatientIDs);
}
